FakeAppLocale class

Inheritance

Constructors

FakeAppLocale({required String languageCode, String? scriptCode, String? countryCode})

Properties

build → TranslationBuilder<FakeAppLocale, FakeTranslations>
Gets a new translation instance. LocaleSettings has no effect here. Suitable for dependency injection and unit tests.
no setteroverride
countryCode → String?
final
hashCode → int
The hash code for this object.
no setterinherited
languageCode → String
final
languageTag → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scriptCode → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sameLocale(BaseAppLocale<BaseAppLocale, BaseTranslations> other) → bool
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited