TranslationMetadata<E extends BaseAppLocale<E, T>, T extends BaseTranslations<E, T>> class

Metadata instance hold by the root translation class.

Constructors

TranslationMetadata({required E locale, required Map<String, Node> overrides, required PluralResolver? cardinalResolver, required PluralResolver? ordinalResolver, int s = 0})

Properties

cardinalResolver → PluralResolver?
final
getTranslation → dynamic Function(String path)
no setter
hashCode → int
The hash code for this object.
no setterinherited
locale → E
final
ordinalResolver → PluralResolver?
final
overrides → Map<String, Node>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s → int
The secret. Used to decrypt obfuscated translation strings.
final

Methods

d(List<int> chars) → String
Decrypts the given chars by XOR-ing them with the secret s.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setFlatMapFunction(dynamic func(String path)) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited