GlobalLocaleState class

The GlobalLocaleState storing the global locale. It is shared among all packages of an app.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getLocale() → BaseAppLocale<BaseAppLocale, BaseTranslations>
Gets the current locale.
getStream() → Stream<BaseAppLocale<BaseAppLocale, BaseTranslations>>
Gets the stream of locale changes.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setLocale(BaseAppLocale<BaseAppLocale, BaseTranslations> locale) → void
Sets the locale and notifies all listeners.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → GlobalLocaleState
The singleton instance.
final