TranslationModelBuilder class

Constructors

TranslationModelBuilder()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

build({required BuildModelConfig buildConfig, required Map<String, dynamic> map, BuildModelResult? baseData, bool handleLinks = true, bool shouldEscapeText = true, required String localeDebug}) → BuildModelResult
Builds the i18n model for ONE locale