BuildResult class

the resulting output strings It can either be rendered as a single file or as multiple files.

Constructors

BuildResult({required String header, required Map<I18nLocale, String> translations, required String? flatMap})

Properties

flatMap → String?
final
hashCode → int
The hash code for this object.
no setterinherited
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
translations → Map<I18nLocale, String>
final

Methods

joinAsSingleOutput() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited