I18nData class

represents one locale and its localized strings

Constructors

I18nData({required bool base, required I18nLocale locale, required ObjectNode root, required List<PopulatedContextType> contexts, required List<Interface> interfaces})

Properties

base → bool
final
contexts → List<PopulatedContextType>
final
hashCode → int
The hash code for this object.
no setterinherited
interfaces → List<Interface>
final
locale → I18nLocale
final
root → ObjectNode
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

generationComparator ↔ I18nDataComparator
sorts base locale first, then alphabetically
getter/setter pair