Interface class

The interface model used for generation equals and hash are only dependent on attributes

Constructors

Interface({required String name, required Set<InterfaceAttribute> attributes})

Properties

attributes → Set<InterfaceAttribute>
final
hashCode → int
The hash code for this object.
no setteroverride
hasLists → bool
True, if at least one attribute is a list
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

extend(Set<InterfaceAttribute> otherAttributes) → Interface
Extend this interface with another interface. If an attribute only exists one interface, then make it optional.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

equalAttributes(Set<InterfaceAttribute> a, Set<InterfaceAttribute> b) → bool
satisfyRequiredSet({required Set<InterfaceAttribute> requiredSet, required Set<InterfaceAttribute> testSet}) → bool
True if, every non-optional attribute in requiredSet also exists in testSet. every optional attribute in requiredSet which also exist in testSet must have the same signature.