InterfaceConfig class

The config from build.yaml

Available extensions

Constructors

InterfaceConfig({required String name, required Set<InterfaceAttribute> attributes, required List<InterfacePath> paths})

Properties

attributes → Set<InterfaceAttribute>
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
paths → List<InterfacePath>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toInterface() → Interface

Available on InterfaceConfig, provided by the InterfaceConfigExt extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited