InterfacePath class

Constructors

InterfacePath(String path)

Properties

hashCode → int
The hash code for this object.
no setterinherited
isContainer → bool
true, if the path ends with '.*', all children have the same interface false, otherwise, i.e. this path itself will get an interface
final
path → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited