StringTextNode class

Inheritance

Constructors

StringTextNode({required String path, required String rawPath, required Map<String, String> modifiers, required String raw, required String? comment, required bool shouldEscape, required StringInterpolation interpolation, required CaseStyle? paramCase, Map<String, Set<String>>? linkParamMap})

Properties

comment → String?
finalinherited
content → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
interpolation → StringInterpolation
finalinherited
Set of paths to TextNodes Will be used for 2nd round, determining the final set of parameters
no setteroverride
modifiers → Map<String, String>
finalinherited
paramCase → CaseStyle?
finalinherited
params → Set<String>
Set of parameters. Hello {name}, I am {age} years old -> {'name', 'age'}
no setteroverride
paramTypeMap → Map<String, String>
Plural and context parameters need to have a special parameter type (e.g. num) In a normal case, this parameter and its type will be added at generate stage
no setteroverride
parent → Node?
no setterinherited
path → String
finalinherited
raw → String
The original string
finalinherited
rawPath → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shouldEscape → bool
Several configs, persisted into node to make it easier to copy See updateWithLinkParams
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setParent(Node parent) → void
inherited
toString() → String
A string representation of this object.
override
updateWithLinkParams({required Map<String, Set<String>> linkParamMap, required Map<String, String> paramTypeMap}) → void
Updates content, params and paramTypeMap according to the new linked parameters
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited