SlangFileCollection class

A collection of translation files that can be read in a later step. This is an abstraction to support build_runner and the custom CLI by providing a common FileReader interface.

Constructors

SlangFileCollection({required RawConfig config, required List<TranslationFile> files})

Properties

config → RawConfig
final
files → List<TranslationFile>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

determineInputPath() → String
determineOutputPath() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited