TranslationFile class

Inheritance

Constructors

TranslationFile({required String path, required I18nLocale locale, required String namespace, required FileReader read})

Properties

hashCode → int
The hash code for this object.
no setterinherited
locale → I18nLocale
The inferred locale of this file (by file name, directory name, or config)
final
namespace → String
The inferred namespace of this file (by file name). If no namespaces are used, ignore this field.
final
path → String
finalinherited
read → FileReader
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readAndParse(FileType fileType) → Future<Map<String, dynamic>>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited