ContextNode class

Inheritance
Implemented types

Constructors

ContextNode({required String path, required String rawPath, required Map<String, String> modifiers, required String? comment, required PendingContextType context, required Map<String, TextNode> entries, required String paramName, required bool rich})

Properties

comment → String?
finalinherited
context → PendingContextType
final
entries → Map<String, TextNode>
final
hashCode → int
The hash code for this object.
no setterinherited
modifiers → Map<String, String>
finalinherited
paramName → String
final
parent → Node?
no setterinherited
path → String
finalinherited
rawPath → String
finalinherited
rich → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clone({required bool keepParent, I18nLocale? locale}) → ContextNode
Deep clones the node.
override
getParameters() → Set<AttributeParameter>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setParent(Node parent) → void
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited