ListNode class

Inheritance

Constructors

ListNode({required String path, required String rawPath, required String? comment, required Map<String, String> modifiers, required List<Node> entries})

Properties

comment → String?
finalinherited
entries → List<Node>
final
genericType → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
modifiers → Map<String, String>
finalinherited
parent → Node?
no setterinherited
path → String
finalinherited
rawPath → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values → Iterable<Node>
Child nodes. This is just an alias so we can iterate more easily.
no setteroverride

Methods

clone({required bool keepParent, I18nLocale? locale}) → ListNode
Deep clones the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setGenericType(String genericType) → void
inherited
setParent(Node parent) → void
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited