Node class abstract

the super class of every node

Implementers

Constructors

Node({required String path, required String rawPath, required Map<String, String> modifiers, required String? comment})

Properties

comment → String?
final
hashCode → int
The hash code for this object.
no setterinherited
modifiers → Map<String, String>
final
parent → Node?
no setter
path → String
final
rawPath → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clone({required bool keepParent, I18nLocale? locale}) → Node
Deep clones the node.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setParent(Node parent) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

keyDelimiter → const String