linkAnchor property

String? linkAnchor
final

The absolute path prefix against which relative links (@:.key) are resolved. If null, the parent path of path is used.

Quantities of plural / context nodes use the path of the scope containing the plural / context node instead (set in TranslationModelBuilder).

Implementation

final String? linkAnchor;