ContextType class

Parsed from build config. Enum values may be null. In this case, they will be inferred during model build step.

Constructors

ContextType({required String enumName, required String defaultParameter, required bool generateEnum})

Properties

defaultParameter → String
final
enumName → String
final
generateEnum → bool
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPending() → PendingContextType
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultParameterSlang → const String