PopulatedContextType class

Used for the generate step.

Constructors

PopulatedContextType({required String enumName, required List<String> enumValues, required bool generateEnum})

Properties

enumName → String
final
enumValues → List<String>
final
generateEnum → bool
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited